@@ -24,3 +24,9 @@ class Configuration:
             return self.content.get(key)
         elif isinstance(key, list):
             return {k: self.content.get(k) for k in key}
+
+    def get_full(self):
+        return self.content.copy()
+
+    def set(self, key, value):
+        self.content[key] = value
