@@ -19,3 +19,7 @@ def get_param_names(method):
     sig = inspect.signature(method)
     parameters = [p for p in sig.parameters.values() if p.name != 'self' and p.kind != p.VAR_KEYWORD]
     return sorted([p.name for p in parameters])
+
+
+def call_module_func(module, name, *args, **kwargs):
+    return getattr(module, name)(*args, **kwargs)
